﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Input;
using QuizLib;

namespace WpfQuiz.ViewModel
{
    public class QuizViewModel
    {
        readonly Quiz _quiz;
        List<QuestionViewModel> _questions;
        ICommand _showResultsCmd;

        public QuizViewModel(Quiz quiz)
        {
            _quiz = quiz;
        }

        public string QuizName
        {
            get { return _quiz.QuizName; }
        }

        #region Questions

        public List<QuestionViewModel> Questions
        {
            get
            {
                if (_questions == null)
                {
                    this.CreateQuestions();
                }
                return _questions;
            }
        }

        void CreateQuestions()
        {
            _questions = new List<QuestionViewModel>();
            foreach (Question question in _quiz.Questions)
                _questions.Add(new QuestionViewModel(question));
        }

        #endregion // Questions

        #region ShowResultsCmd

        public ICommand ShowResultsCmd
        {
            get
            {
                if (_showResultsCmd == null)
                {
                    _showResultsCmd = new ShowResultsCommand(this);
                }
                return _showResultsCmd;
            }
        }

        void ShowResults()
        {
            int correctlyAnswered = 0;

            foreach (QuestionViewModel questionVM in this.Questions)
            {
                if (questionVM.WasAnsweredCorrectly)
                    ++correctlyAnswered;
            }

            double percent = ((double)correctlyAnswered / (double)this.Questions.Count) * 100;
            MessageBox.Show("Your score: " + percent + "%");
        }

        private class ShowResultsCommand : ICommand
        {
            readonly QuizViewModel _quiz;

            public ShowResultsCommand(QuizViewModel quiz)
            {
                _quiz = quiz;
            }

            #region ICommand Members

            public bool CanExecute(object parameter)
            {
                return true;
            }

            public event EventHandler CanExecuteChanged;

            public void Execute(object parameter)
            {
                _quiz.ShowResults();
            }

            #endregion
        }

        #endregion // ShowResultsCmd
    }
}